class ScannersController < ApplicationController
  def self.set_target_before
    super + [:scan, :ping, :ping_v2]
  end

  model_data_store(Scanner)

  def create
    params = model_params
    return render json: {error: 'Could not create scanner.'}, status: :unprocessable_entity if params[:type].nil?

    @model = Scanner.new(params)
    @model.add_rules(rule_params[:rules_to_add])

    if @model.save
      render :show, status: :ok
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def bulk_create
    render json: bulk_create_save, status: :ok
  end

  def update
    params = model_params
    return render json: {error: 'Could not create scanner.'}, status: :unprocessable_entity if params[:type].nil?

    @model.assign_attributes(params)
    @model.add_rules(rule_params[:rules_to_add])

    if @model.save
      render :show, status: :ok
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def options
    render json: Scanner.options, status: :ok
  end

  # GET /scanners/:id/scan
  def scan
    response = @model.scan

    if response[:success] || response[:scan_failed]
      render json: @model
    else
      render json: {error: response[:error]}, status: :unprocessable_entity
    end
  end

  # legacy endpoint that needs a plain text response
  def ping
    response = @model.ping

    if response[:success]
      render plain: "success"
    else
      render plain: "Failed", status: :unprocessable_entity
    end
  end

  def ping_v2
    response = @model.ping

    if response[:success]
      render json: {success: true}, status: :ok
    else
      render json: {success: false, error: response[:error]}, status: :unprocessable_entity
    end
  end

  private

  def bulk_create_model(scanner_def)
    make = scanner_def[:type].split("/")[0]
    type = scanner_def[:type].split("/")[1]
    scanner_type = Scanner.make_model_to_type(make, type)
    Scanner.new(
      name: scanner_def[:name],
      ip_address: scanner_def[:ip_address],
      type: scanner_type,
      min_scan_length: scanner_def[:min_scan_length]
    )
  end


  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    p = params.fetch(:scanner).permit( :name,
                                   :ip_address,
                                   :type,
                                   :last_read_value,
                                   :last_read_time,
                                   :rulesToAdd,
                                   :rulesToDelete,
                                   :min_scan_length,
                                   :parameters => {})
    p[:parameters] = p[:parameters].to_json
    type_data = p[:type].split('/')
    p[:type] = Scanner.make_model_to_type(type_data[0], type_data[1])
    p
  end

  def rule_params
    params.fetch(:scanner).permit(rules_to_add: [:operation, :priority, :start_position, :end_position, :value])
  end

  def bulk_create_extra_params
    [:name, :ip_address, :type, :min_scan_length]
  end
end