import * as React from 'react';
import {Layout, Providers} from '@rx-suite/ui';
import './stores';
import {RxAppModel} from '@rx-suite/stores';
import 'react-table/react-table.css';
import {observer} from "mobx-react-lite";
import { RxAppStore } from '@rx-suite/stores';
import { subscribe } from "@rx-suite/data";
import {LinearProgress} from "@material-ui/core";
import { t } from "@lingui/macro"
import {routes} from "./routes";

subscribe();
export default observer(() => {
    const [ messages, setMessages ] = React.useState<any>(null);
    const model = RxAppStore.selectedModel as RxAppModel;
    React.useEffect(() => {
        if (model) {
            const getMessages = async () => {
                const compiledMessages = await import(`../../../locales/${model.language}/messages.mjs`);
                setMessages(compiledMessages.messages);
            }
            model.setTitleBase(t`Rx-Scanners`);
            getMessages();
        }
    }, [model]);
    if(!model || !messages) {
        return <LinearProgress />
    }
    return (
        <Providers theme={model.theme} language={model.language} messages={messages}>
            <Layout routes={routes}/>
        </Providers>
    )
});

