import React from "react";
import {FormProps, ModelActionButton, ModelProvider} from "@rx-suite/ui";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faSatelliteDish, faScanner} from "@rx-suite/pro-solid-svg-icons";
import {useSnackbar} from "notistack";
import {ScannerModel} from "../stores/ScannerStore";
import {createStyles, makeStyles, Theme} from "@material-ui/core";
import {blue} from "@material-ui/core/colors";

type ScannerActionsProps = {
    model: ScannerModel
} & Omit<FormProps, 'model'>

const useStyles = makeStyles((theme: Theme) =>
    createStyles({
        scanButton: {
            backgroundColor: blue[800],
            '&:hover': {
                backgroundColor: blue[900],
            },
        }
    })
);

export const ScannerActions: React.FunctionComponent<ScannerActionsProps> = ({ model }) => {
    const {enqueueSnackbar} = useSnackbar();
    const classes = useStyles();

    return (
        <ModelProvider value={model}>
            <ModelActionButton
                name={'ping'}
                text={'ping'}
                startIcon={<FontAwesomeIcon icon={faSatelliteDish}/>}
            />
            <ModelActionButton
                name={'scan'}
                text={'test'}
                startIcon={<FontAwesomeIcon icon={faScanner}/>}
                successHandler={() => {
                    if(model.last_scan_successful){
                        enqueueSnackbar(`[${model.name}] result: ${model.last_read_value}`, { variant: 'success' });
                    }else{
                        enqueueSnackbar(`[${model.name}] failed to read`, { variant: 'error' });
                    }
                }}
                className={classes.scanButton}
            />
        </ModelProvider>
    )
};