import React from "react";
import { t } from "@lingui/macro";
import {SelectField} from "@rx-suite/ui";
import {ScannerOptionStore} from "../../stores/ScannerOptionStore";
import {Filter, ReactTableFunction} from "react-table";

export const useScannerTypeColumn = () => {
    const typeOptions = React.useMemo(() => {
        return ScannerOptionStore.models.map((option => ({
            label: `${option.type}`,
            value: `${option.type}`
        })))
    }, [ScannerOptionStore.models]);

    return {
            Header: t`Type`,
            accessor: 'type',
            id: 'type',
            Cell: (cellInfo: { value: string }) => {
                return cellInfo.value;
            },
            filterable: true,
            Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction }) => (
                <SelectField
                    options={typeOptions}
                    onChange={(name, value) => onChange(value)}
                    value={filter ? filter.value : ""}
                    clearable
                />
            )
        }
};