import * as React from "react";
import {FormProps, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {useEffect, useMemo} from "react";
import {ScannerModel} from "../../../stores/ScannerStore";
import {Iqh1FpV1Parameters} from "../../../components/scanner_parameters/Iqh1FpV1Parameters";
import {PrepIQH1FPV1Parameters} from "../../../hooks/PrepIQH1FPV1Parameters";
import {ScannerOptionStore} from "../../../stores/ScannerOptionStore";
import {ScannerTypeSelect} from "../../../components/form/ScannerTypeSelect";

export const ScannerConfigurationTab: React.FunctionComponent<FormProps> = observer(({model}) => {
    useEffect(() => {
        ScannerOptionStore.getOptions();
    }, []);

    const scannerExtraParams = useMemo(() => {
        if(model.viewModel.scanner_model === 'IQH1-FP-V1') {
            PrepIQH1FPV1Parameters(model as ScannerModel);
            return <Iqh1FpV1Parameters model={model}/>
        } else {
            return undefined
        }
    }, [model.viewModel.scanner_model])

    return <React.Fragment>
        <ModelInput name={"name"}/>
        <ScannerTypeSelect/>
        {scannerExtraParams}
        <ModelInput name={"ip_address"}/>
        <ModelInput name={"min_scan_length"}/>
    </React.Fragment>
})