import * as React from "react";
import {AssociatedModelTable, FormProps, makeColumn} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {ScannerRuleModel, ScannerRuleStore} from "../../../stores/ScannerRuleStore";
import {useMemo} from "react";
import {t} from '@lingui/macro';
import {ScannerRuleDialogForm} from "../../../components/scanner_rules/ScannerRuleDialogForm";

export const ScannerRuleTab: React.FunctionComponent<FormProps> = observer(({model}) => {
    const parameterColumn = useMemo(() => {
        return {
            Header: t`Parameter(s)`,
            accessor: (rule: ScannerRuleModel) => rule,
            id: 'parameters',
            Cell: (CellInfo: {value: ScannerRuleModel}) => {
                switch(CellInfo.value.viewModel.operation) {
                    case 'append':
                    case 'prepend':
                        return CellInfo.value.viewModel.value
                    case 'delete':
                        return `Start position=${CellInfo.value.viewModel.start_position}, End position=${CellInfo.value.viewModel.end_position}`
                }
            }
        }
    }, [])

    const columns = useMemo(() => {
        return [
            makeColumn('priority', t`Priority`, 'string'),
            makeColumn('operation', t`Operation`, 'string'),
            parameterColumn
        ];
    }, [])

    return <React.Fragment>
        <AssociatedModelTable
            baseModel={model}
            columns={columns}
            associatedColumnName={'rules_to_add'}
            DialogForm={ScannerRuleDialogForm}
            store={ScannerRuleStore}
            defaultFiltered={[{id: 'scanner_id', value: model.getId()}]}
            defaultOrdered={[{id: 'priority'}]}
            replacementActions={
                {
                    Read: () => null
                }
            }
            suppressWrapper
        />
    </React.Fragment>
})