import {attribute, DataStore, Model, model} from "@rx-suite/data";
import {action, computed, observable, runInAction} from "mobx";

class ScannerOptionDataStore<T extends Model> extends DataStore<T> {
    @observable
    fetchingOptions: boolean = false;

    @action
    async getOptions() {
        if(this.fetchingOptions) { return; }

        runInAction(() => {
            this.fetchingOptions = true;
        })

        const resp = await this.transportLayer.fetch('/options', {method: 'GET'})

        const data = await resp.json() as {model: string, make: string}[];

        if(data.length > 0) {
            data.forEach((data) => {
                const newModel = this.createModel(data);
                this.setModel(newModel);
            })
        }
    }
}

@model({
    transportLayer: "/api/scanners",
    storeClass: ScannerOptionDataStore
})

export class ScannerOptionModel extends Model {
    @computed
    get type(): ScannerType {
        return `${this.make}/${this.model}` as ScannerType;
    }

    //LEGACY ATTRIBUTE - use type instead
    @attribute()
    make: string = "";

    //LEGACY ATTRIBUTE - use type instead
    @attribute()
    model: string = "";

    constructor() {
        super();
        super.setup();
    }
}

export type ScannerType = 'Datalogic/Matrix 120' | 'Sick/CLV 62x' | 'Wenglor/B50'

export const ScannerOptionStore = ScannerOptionModel.store as unknown as ScannerOptionDataStore<ScannerOptionModel>;

ScannerOptionStore.getOptions(); // Since this is not a real store, we have to eager load manually