module ScannerHandler
  class SickClv62xScannerHandler < BaseScannerHandler

    def initialize(model)
      super(model.name, model.ip_address, 2111, model.min_scan_length)
    end

    private

    def emit_scan
      @connection_client.send_message(scan_command)

      # scan confirmation
      response = ''
      while (char = @connection_client.read_response(1)[0]) != 0x03.chr do
        response << char
      end

      # strip excess confirmation
      response = ''
      while (char = @connection_client.read_response(1)[0]) == 0x03.chr do
        #no-op
      end
      if char && char != 0x03.chr
        response << char
      end

      # get the real message
      while (char = @connection_client.read_response(1)[0]) != 0x03.chr do
        response << char
      end

      result = response.split("\r\n")[2] # I have <ZERO> idea how consistent this is. Sick's documentation is awful.

      raise FailedToRead unless scan_response_ok?(response)

      result
    end

    def scan_response_ok?(response)
      return false unless super(response)
      response != '*NoRead*'
    end

    concerning :Commands do
      private

      def scan_sequence
        [
          {code: :start, bits: 8, literal: 0x02}, # <stx>
          {code: :open_read_gate, bits: 136, literal: "sMN mTCgateondiag"},
          {code: :end, bits: 8, literal: 0x03}, # <etx>
        ]
      end
    end
  end
end