module ScannerHandler
  class WenglorB50ScannerHandler < BaseScannerHandler

    def initialize(model)
      super(model.name, model.ip_address, 32001, model.min_scan_length)

      @response_client = ScannerConnection::ScannerConnectionWrapper.new(model.ip_address, 32002)
    end

    def close_connection
      super

      @response_client.close
    end

    private

    # This scanner operates by sending a read requests to port 32001 and it responds with <TOk/> on the same port,
    # But the data that we want is broadcast on the port 32002, so we need to open a connection to that port first and wait.
    # Because of this, we need to start the mutex and open a connection earlier then when we will read from it.
    def emit_scan
      # The response port must be opened before we emit out scan request
      @response_client.ensure_connection

      @connection_client.send_message(scan_command)

      status = @connection_client.read_response(6)[0]

      raise FailedToRead unless scan_status_ok?(status)

      response = ''

      while (char = @response_client.read_response(1)[0]) != ';' do
        log "Character to add to response_content: #{char}"
        response << char
      end

      # Scanners sends garbage commas
      response = response.split(',')[0]

      raise FailedToRead unless scan_response_ok?(response)

      response
    end

    def scan_status_ok?(status)
      status == '<TOk/>'
    end

    def scan_response_ok?(response)
      return false unless super(response)
      response != 'Error###'
    end

    concerning :Commands do
      private

      def scan_sequence
        [
          {code: :start, bits: 8, literal: 0x3C}, # <
          {code: :open_read_gate, bits: 8, literal: 0x54}, # T
          {code: :end, bits: 16, literal: "/>"}, # />
        ]
      end
    end
  end
end