class AddTypeToScanners < ActiveRecord::Migration[6.1]
  class Scanner < ActiveRecord::Base
    self.inheritance_column = :_type_disabled
  end

  class WenglorB50 < Scanner
  end

  class DatalogicMatrix120 < Scanner
  end

  class PepperlFuchsIqh1FpV1 < Scanner
  end

  class SickClv62x < Scanner
  end

  def scanner_model_to_class_name(model)
    {
      'CLV 62x' => 'SickClv62x',
      'IQH1-FP-V1' => 'PepperlFuchsIqh1FpV1',
      'Matrix 120' => 'DatalogicMatrix120',
      'B50' => 'WenglorB50'
    }[model]
  end

  def class_name_to_make_model(name)
    {
      'SickClv62x' => ['Sick', 'CLV 62x'],
      'PepperlFuchsIqh1FpV1' => ['Pepperl+Fuchs', 'IQH1-FP-V1'],
      'DatalogicMatrix120' => ['Datalogic', 'Matrix 120'],
      'WenglorB50' => ['Wenglor', 'B50']
    }[name]
  end

  def up
    add_column :scanners, :type, :string

    Scanner.connection.schema_cache.clear!
    Scanner.reset_column_information

    Scanner.find_each do |scanner|
      scanner.update(type: scanner_model_to_class_name(scanner.scanner_model))
    end

    remove_column :scanners, :make
    remove_column :scanners, :scanner_model

    drop_table :scanner_models
    drop_table :scanner_makes
  end

  def down
    create_table :scanner_makes do |t|
      t.string :make
      t.timestamps
    end

    create_table :scanner_models do |t|
      t.string :scanner_model
      t.timestamps

      t.belongs_to :scanner_make, foreign_key: { on_delete: :cascade }
    end

    add_column :scanners, :make, :string
    add_column :scanners, :scanner_model, :string

    Scanner.connection.schema_cache.clear!
    Scanner.reset_column_information

    Scanner.find_each do |scanner|
      type = scanner.type
      make,model = class_name_to_make_model(type)
      scanner.update(make: make, scanner_model: model)
    end

    remove_column :scanners, :type
  end
end
